==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
var PercentagePriceOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentagePriceOscillatorIndicatorDescriptionMetadata, _super);
    function PercentagePriceOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.g(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.d = function (a) {
        PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
        a.u("PercentagePriceOscillatorIndicator", function () { return new PercentagePriceOscillatorIndicatorDescription(); });
        a.t("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
}(Base));
export { PercentagePriceOscillatorIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PercentagePriceOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { PercentagePriceOscillatorIndicatorDescription } from "./PercentagePriceOscillatorIndicatorDescription";
/**
 * @hidden
 */
var PercentagePriceOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PercentagePriceOscillatorIndicatorDescriptionMetadata, _super);
    function PercentagePriceOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentagePriceOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (PercentagePriceOscillatorIndicatorDescriptionMetadata.a == null) {
            PercentagePriceOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PercentagePriceOscillatorIndicatorDescriptionMetadata.c(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(PercentagePriceOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.d = function (a) {
        PercentagePriceOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("PercentagePriceOscillatorIndicator", function () { return new PercentagePriceOscillatorIndicatorDescription(); });
        a.z("PercentagePriceOscillatorIndicator", PercentagePriceOscillatorIndicatorDescriptionMetadata.a);
    };
    PercentagePriceOscillatorIndicatorDescriptionMetadata.$t = markType(PercentagePriceOscillatorIndicatorDescriptionMetadata, 'PercentagePriceOscillatorIndicatorDescriptionMetadata');
    PercentagePriceOscillatorIndicatorDescriptionMetadata.a = null;
    return PercentagePriceOscillatorIndicatorDescriptionMetadata;
}(Base));
export { PercentagePriceOscillatorIndicatorDescriptionMetadata };
